@@ -12,19 +12,19 @@
 //! In the basic case, customers should not need to use this module. A default implementation of Hyper
 //! with `rustls` will be constructed during client creation. However, if you are creating a Smithy
 //! [`Client`](crate::Client), directly, use the `https()` method to match the default behavior:
-//! ```rust
-//! use aws_smithy_client::Client;
+//! ```no_run
+//! use aws_smithy_client::Builder;
 //! use aws_smithy_client::erase::DynConnector;
 //!
 //! // TODO: replace this with your middleware
 //! type MyMiddleware = tower::layer::util::Identity;
-//! let client = Client::<DynConnector, MyMiddleware>::https();
+//! let client = Builder::<DynConnector, MyMiddleware>::dyn_https().build();
 //! ```
 //!
 //! ### Create a Hyper client with a custom timeout
 //! One common use case for constructing a connector directly is setting `CONNECT` timeouts. Since the
 //! internal connector is cheap to clone, you can also use this to share a connector between multiple services.
-//! ```rust
+//! ```no_run
 //! use std::time::Duration;
 //! use aws_smithy_client::{Client, conns, hyper_ext};
 //! use aws_smithy_client::erase::DynConnector;
@@ -42,7 +42,7 @@ use std::error::Error;
 use std::sync::Arc;
 
 use http::Uri;
-use hyper::client::connect::Connection;
+use hyper::client::connect::{Connected, Connection};
 use tokio::io::{AsyncRead, AsyncWrite};
 use tower::{BoxError, Service};
 
@@ -52,6 +52,8 @@ use aws_smithy_http::body::SdkBody;
 use aws_smithy_http::result::ConnectorError;
 use aws_smithy_types::retry::ErrorKind;
 
+use crate::erase::DynConnector;
+use crate::never::stream::EmptyStream;
 use crate::{timeout, Builder as ClientBuilder};
 
 use self::timeout_middleware::{ConnectTimeout, HttpReadTimeout, HttpTimeoutError};
@@ -166,7 +168,7 @@ fn find_source<'a, E: Error + 'static>(err: &'a (dyn Error + 'static)) -> Option
 /// Construct a HyperAdapter with the default HTTP implementation (rustls). This can be useful when you want to share a Hyper connector
 /// between multiple Smithy clients.
 ///
-/// ```rust
+/// ```no_run
 /// use tower::layer::util::Identity;
 /// use aws_smithy_client::{conns, hyper_ext};
 /// use aws_smithy_client::erase::DynConnector;
@@ -250,20 +252,22 @@ impl Builder {
     }
 }
 
-#[cfg(any(feature = "rustls", feature = "native_tls"))]
-impl<M> crate::Client<crate::erase::DynConnector, M>
+#[cfg(any(feature = "rustls", feature = "native-tls"))]
+impl<M> crate::Builder<crate::erase::DynConnector, M>
 where
     M: Default,
-    M: crate::bounds::SmithyMiddleware<crate::erase::DynConnector> + Send + Sync + 'static,
 {
-    /// Create a Smithy client that uses HTTPS and the [standard retry
+    /// Create a Smithy client builder with an HTTPS connector and the [standard retry
     /// policy](crate::retry::Standard) over the default middleware implementation.
     ///
+    /// *Note:* This function **does not** set a sleep implementation to ensure that [`default_async_sleep`](crate::Builder::default_async_sleep)
+    /// or [`set_sleep_impl`](crate::Builder::set_sleep_impl) is called.
+    ///
     /// For convenience, this constructor type-erases the concrete TLS connector backend used using
     /// dynamic dispatch. This comes at a slight runtime performance cost. See
     /// [`DynConnector`](crate::erase::DynConnector) for details. To avoid that overhead, use
     /// [`Builder::rustls`](ClientBuilder::rustls) or `Builder::native_tls` instead.
-    pub fn https() -> Self {
+    pub fn dyn_https() -> Self {
         #[cfg(feature = "rustls")]
         let with_https = |b: ClientBuilder<_>| b.rustls();
         // If we are compiling this function & rustls is not enabled, then native-tls MUST be enabled
@@ -272,8 +276,27 @@ where
 
         with_https(ClientBuilder::new())
             .middleware(M::default())
+            .map_connector(DynConnector::new)
+    }
+}
+
+#[cfg(any(feature = "rustls", feature = "native_tls"))]
+impl<M> crate::Client<crate::erase::DynConnector, M>
+where
+    M: Default,
+    M: crate::bounds::SmithyMiddleware<crate::erase::DynConnector> + Send + Sync + 'static,
+{
+    /// Create a Smithy client builder with an HTTPS connector and the [standard retry
+    /// policy](crate::retry::Standard) over the default middleware implementation.
+    ///
+    /// For convenience, this constructor type-erases the concrete TLS connector backend used using
+    /// dynamic dispatch. This comes at a slight runtime performance cost. See
+    /// [`DynConnector`](crate::erase::DynConnector) for details. To avoid that overhead, use
+    /// [`Builder::rustls`](ClientBuilder::rustls) or `Builder::native_tls` instead.
+    pub fn dyn_https() -> Self {
+        ClientBuilder::<DynConnector, M>::dyn_https()
+            .default_async_sleep()
             .build()
-            .into_dyn_connector()
     }
 }
 
@@ -283,15 +306,8 @@ impl<M, R> ClientBuilder<(), M, R> {
     pub fn rustls(self) -> ClientBuilder<Adapter<crate::conns::Https>, M, R> {
         self.connector(Adapter::builder().build(crate::conns::https()))
     }
-
-    /// Connect to the service over HTTPS using Rustls.
-    ///
-    /// This is exactly equivalent to [`Builder::rustls`](ClientBuilder::rustls). If you instead wish to use `native_tls`,
-    /// use `Builder::native_tls`.
-    pub fn https(self) -> ClientBuilder<Adapter<crate::conns::Https>, M, R> {
-        self.rustls()
-    }
 }
+
 #[cfg(feature = "native-tls")]
 impl<M, R> ClientBuilder<(), M, R> {
     /// Connect to the service over HTTPS using the native TLS library on your platform.
@@ -594,6 +610,13 @@ mod timeout_middleware {
     }
 }
 
+/// Make `EmptyStream` compatible with Hyper
+impl Connection for EmptyStream {
+    fn connected(&self) -> Connected {
+        Connected::new()
+    }
+}
+
 #[cfg(test)]
 mod test {
     use std::io::{Error, ErrorKind};
